###############################################################################
# SendEmail.pm                                                                #
###############################################################################
# YaBB: Yet another Bulletin Board                                            #
# Open-Source Community Software for Webmasters                               #
# Version:        YaBB 2.7.00                                                 #
# Distributed by: http://www.yabbforum.com                                    #
# =========================================================================== #
# Copyright (c) 2000-2017 YaBB (www.yabbforum.com) - All Rights Reserved.     #
# Software by:  The YaBB Development Team                                     #
#               with assistance from the YaBB community.                      #
###############################################################################
use strict;
no strict qw(refs);
use warnings;
our $sendemailpmver = 'YaBB 2.7.00 $Revision: 0.10 $';
our ($action);
$action ||= q{};
if ( $action eq 'detailedversion' ) { return 1; }

our (
    $abbr_lang,             $allow_hide_email,   $boardurl,
    $date,                  $enable_spell_check, $flood_text,
    $iamadmin,              $iamgmod,            $iamguest,
    $iammod,                $mbname,             $post_speed_count,
    $regcheck,              $scripturl,          $send_email,
    $send_email_spellcheck, $sendemail,          $sendemail_selfcopy,
    $showcheck,             $uid,                $user,
    $username,              $webmaster_email,    $yyhtml_root,
    $yyinlinestyle,         $yymain,             $yynavigation,
    $yytitle,               %floodtxt,           %FORM,
    %INFO,                  %link,               %micon_bg,
    %sendemail_txt,         %spell_check,        %useraccount,
);
require Sources::SpamCheck;

load_language('Mods/SendEmail');
load_language('Post');

our $allow_send_email = SendEmailPerms();

if (   !$send_email
    || !$allow_send_email
    || $iamguest
    || !${ $uid . $username }{'en_send_email'} )
{
    fatal_error('not_allowed');
}

sub SendEmail {
    $user = $INFO{'to'};
    if ( !load_user($user) ) { fatal_error('no_profile_exists'); }

    if (   ${ $uid . $user }{'hidemail'}
        && $allow_hide_email
        && !${ $uid . $user }{'en_re_email'}
        && !$iamadmin )
    {
        fatal_error('not_allowed');
    }

    my $member_email = enc_email(
        ${ $uid . $user }{'email'},
        ${ $uid . $user }{'email'},
        q{}, q{}
    );
    my $show_member_email = q{};
    if ($iamadmin) { $show_member_email = qq~($member_email)~; }

    # SpellChecker start
    get_micon();
    $yymain .= qq~
<form action="$scripturl?action=sendemail2" method="post" name="email" onsubmit="return CheckEmailFields();">
<table class="tabtitle">
    <tr>
        <th style="padding-left:1%"><img src="$micon_bg{'email'}" alt="" /> $sendemail_txt{'01'} ${$uid.$user}{'realname'}</th>
    </tr>
    </table>
    <table class="pad_3px" style="table-layout: fixed">
        <colgroup>
            <col style="width:25%" />
            <col style="width:75%" />
        </colgroup>
        <tr>
            <td class="windowbg right vtop" style="font-weight: bold;">
                <label>$sendemail_txt{'02'}:</label>
            </td>
            <td class="windowbg2">$link{$user} $show_member_email</td>
        </tr><tr>
            <td class="windowbg vtop right" style="font-weight: bold;">
                <label for="email_subject">$sendemail_txt{'03'}:</label>
            </td>
            <td class="windowbg2"><input type="text" name="email_subject" id="email_subject" size="50" maxlength="80" style="width: 400px;" /></td>
        </tr><tr>
            <td class="windowbg vtop right" style="font-weight: bold;"><label for="email_message">$sendemail_txt{'04'}:</label></td>
            <td class="windowbg2">
                <div style="float: left;">
                    <textarea cols="60" rows="15" name="email_message" id="email_message" style="width: 550px;"></textarea>
                </div>
            </td>
        </tr><tr>
            <td class="windowbg vtop right" style="font-weight: bold;"><label for="email_selfcopy">$sendemail_txt{'05'}</label></td>
            <td class="windowbg2"><input type="checkbox" name="email_selfcopy" id="email_selfcopy" />
                <br /><span class="small">$sendemail_txt{'06'}: ${$uid.$username}{'email'}</span>
            </td>
        </tr>~;
    if ( $regcheck && !$iamadmin && !$iamgmod ) {
        require Sources::Decoder;
        validation_code();
        $yymain .= qq~<tr>
            <td class="windowbg vtop right"><label for="verification">$flood_text</label></td>
            <td class="windowbg2">$showcheck</td>
        </tr><tr>
            <td class="windowbg vtop right" style="font-weight: bold;"><label for="verification">$floodtxt{'3'}:</label></td>
            <td class="windowbg2"><input type="text" maxlength="30" name="verification" id="verification" size="30" /></td>
        </tr>~;
    }
    $yymain .= qq~<tr>
            <td class="catbg center" colspan="2" style="height: 50px;">
                <input type="hidden" name="username" value="$useraccount{$user}" />
                <input type="submit" value="$sendemail_txt{'07'}" accesskey="s" class="button" />
            </td>
        </tr>
    </table>
</form>
<script type="text/javascript">
document.email.email_subject.focus();

function CheckEmailFields() {
if (document.email.email_subject.value == '') {
    alert("$sendemail_txt{'08'}");
    document.email.email_subject.focus();
    return false;
}
if (document.email.email_message.value == '') {
    alert("$sendemail_txt{'09'}");
    document.email.email_message.focus();
    return false;
}~ . (
        $regcheck && !$iamadmin && !$iamgmod
        ? qq~
if (document.email.verification.value == '') {
    alert("$sendemail_txt{'10'}");
    document.email.verification.focus();
    return false;
}~
        : q{}
      )
      . qq~
return true;
}
</script>~;

    $yytitle      = "$sendemail_txt{'01'} ${$uid.$user}{'realname'}";
    $yynavigation = qq~&rsaquo; $sendemail_txt{'07'}~;
    template();
    return;
}

sub SendEmail2 {

    $user = $FORM{'username'};
    if ( !load_user($user) ) { fatal_error('no_profile_exists'); }

    require Sources::Mailer;
    load_language('Email');

    my $recipientname  = ${ $uid . $user }{'realname'};
    my $recipientemail = ${ $uid . $user }{'email'};
    my $yourname       = ${ $uid . $username }{'realname'};
    my $youremail      = ${ $uid . $username }{'email'};
    my $emailsubject   = $FORM{'email_subject'};
    my $emailmessage   = $FORM{'email_message'};
    my $emailselfcopy  = $FORM{'email_selfcopy'};
    $yourname =~ s/\A\s+//;
    $yourname =~ s/\s+\Z//;
    $youremail =~ s/\A\s+//;
    $youremail =~ s/\s+\Z//;
    $emailmessage =~ s/\r(?=\n*)//g;

    if ( !$emailsubject ) { fatal_error('no_subject'); }
    if ( !$emailmessage ) { fatal_error('no_message'); }

    if ( $regcheck && !$iamadmin && !$iamgmod ) {
        require Sources::Decoder;
        validation_check( $FORM{'verification'} );
    }

    # Spam detection start
    my $spamdetected = spamcheck("$emailsubject $emailmessage");
    if ( !${ $uid . $FORM{$username} }{'spamcount'} ) {
        ${ $uid . $FORM{$username} }{'spamcount'} = 0;
    }
    if ( !$iamadmin && !$iamgmod && !$iammod ) {
        if ( $spamdetected == 1 ) {
            ${ $uid . $username }{'spamcount'}++;
            ${ $uid . $username }{'spamtime'} = $date;
            user_account( $username, 'update' );
            my $spam_hits_left_count =
              $post_speed_count - ${ $uid . $username }{'spamcount'};
            fatal_error('tsc_alert');
        }
    }

    # Spam detection end

    my $email_message = template_email(
        $sendemail,
        {
            'recipientname' => $recipientname,
            'yourname'      => $yourname,
            'emailsubject'  => $emailsubject,
            'emailmessage'  => $emailmessage
        }
    );
    sendmail(
        $recipientemail, "$emailsubject",
        $email_message,  "$yourname <$youremail>"
    );

    if ($emailselfcopy) {
        my $copy_emailmessage = template_email(
            $sendemail_selfcopy,
            {
                'yourname'      => $yourname,
                'recipientname' => $recipientname,
                'emailsubject'  => $emailsubject,
                'emailmessage'  => $emailmessage
            }
        );
        sendmail( $youremail, "$emailsubject", $copy_emailmessage,
            "$mbname <$webmaster_email>" );
    }

    $yymain .= qq~
<table class="tabtitle">
    <tr>
        <th style="padding-left:1%"><img src="$micon_bg{'email'}" alt="" /> $sendemail_txt{'11'} $recipientname</th>
    </tr>
</table>
<table class="pad_3px" style="table-layout: fixed">
    <tr>
        <td class="windowbg center vtop" style="padding: 20px;">
            <span style="font-weight: bold;">$sendemail_txt{'12'} $link{$user}.</span><br /><br />
           &bull; <a href="$scripturl">$sendemail_txt{'13'}</a><br /><br />
           <span class="small">$sendemail_txt{'14'}</span>
        </td>
     </tr>
</table>~;

    $yyinlinestyle =
      qq~<meta http-equiv="refresh" content="5; url=$scripturl" />~;
    $yytitle      = "$sendemail_txt{'11'} $recipientname";
    $yynavigation = qq~&rsaquo; $sendemail_txt{'15'}~;
    template();
    return;
}

1;
